#[non_exhaustive]pub enum PqcVerifyError {
WrongLength,
Mismatch,
}Expand description
Failure modes for PqcVerifier::verify operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongLength
Signature buffer was not the expected fixed length for the PQC scheme (e.g., 3309 bytes for ML-DSA 65).
Mismatch
Signature did not validate against the message under the pinned verifying key.