#[non_exhaustive]pub enum DeferReason {
SchedulerBusy,
BudgetExceeded,
}Expand description
Why a scheduled action was deferred to the next tick.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SchedulerBusy
Per-step scheduler dispatch budget was reached.
BudgetExceeded
Per-instance resource budget would be exceeded by running this action now.