pub struct EventMask(/* private fields */);Expand description
Event-class filter for observer registration. One bit per
KernelEvent variant; an observer registered with a mask only
receives events whose variant bit is set. EventMask::ALL
(the Default) matches every variant — backward-compatible with
the unfiltered Kernel::register_observer path.
Bit assignments are part of the public surface; new variants must take the next free bit (no repurposing).
Implementations
Sourceimpl EventMask
impl EventMask
Sourcepub const ACTION_EXECUTED: Self
pub const ACTION_EXECUTED: Self
Match KernelEvent::ActionExecuted.
Sourcepub const ACTION_FAILED: Self
pub const ACTION_FAILED: Self
Match KernelEvent::ActionFailed.
Sourcepub const EFFECT_FAILED: Self
pub const EFFECT_FAILED: Self
Match KernelEvent::EffectFailed.
Sourcepub const OBSERVER_PANIC: Self
pub const OBSERVER_PANIC: Self
Match KernelEvent::ObserverPanic.
Sourcepub const OBSERVER_EVICTED: Self
pub const OBSERVER_EVICTED: Self
Match KernelEvent::ObserverEvicted.
Sourcepub const SIGNAL_DROPPED: Self
pub const SIGNAL_DROPPED: Self
Match KernelEvent::SignalDropped.
Sourcepub const MODULE_FORCE_UNLOADED: Self
pub const MODULE_FORCE_UNLOADED: Self
Sourcepub const ACTION_DEFERRED: Self
pub const ACTION_DEFERRED: Self
Sourcepub const OBSERVERS_FLUSHED: Self
pub const OBSERVERS_FLUSHED: Self
Sourcepub const DOMAIN_EVENT_EMITTED: Self
pub const DOMAIN_EVENT_EMITTED: Self
Sourceimpl EventMask
impl EventMask
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl EventMask
impl EventMask
Sourcepub const fn iter(&self) -> Iter<EventMask>
pub const fn iter(&self) -> Iter<EventMask>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<EventMask>
pub const fn iter_names(&self) -> IterNames<EventMask>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.