DenyReason

Enum DenyReason 

#[non_exhaustive]
pub enum DenyReason { CapabilityDenied, InstanceMismatch, OperationRestricted, NotImplemented, }
Reason an effect was denied during authorization.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


CapabilityDenied

CapabilityMask lacks the bit required by the principal/op pair.



InstanceMismatch

Effect’s branded instance does not match the authorize call site.



OperationRestricted

Op type is restricted under the current policy (reserved for future per-op deny refinement).



NotImplemented

Authorization path not yet wired for this op variant.